views
======
**Module**: :mod:`espressodb.notifications.views`

.. currentmodule:: espressodb.notifications.views

.. autosummary::
    NotificationsView
    HasReadView

--------

.. automodule:: espressodb.notifications.views
    :members:
    :special-members:
